# MaterioMiner

## Description
This project contains named-entity recognition (NER) datasets for some materials science and engineering (MSE) publications and utility functions to handle the data. The scope of the scholarly articles used as a basis is crystallographic defects, microstructure, mechanical properties in particular fatigue. Each annotation corresponds to a class in a materials science domain ontology called [materials mechanics ontology](https://w3id.org/pmd/materials-mechanics-ontology). This should prospectively enable linking materials knowledge and data to facilitate training neurosymbolic machine learning models.

Two dataset variants are published: 
- coarse-granular named-entity recognition (CG-NER) where the annotated concepts are high-level ontological classes
- fine-granular named-entity recognition (FG-NER) where the annotated concepts are low-level ontological classes

Aside from the link to the ontology a characterstic of the dataset is its high degree of of annotation. Namely, 179 distinct ontological classes and 27% of all tokens are annotated in the fine-granular dataset.

## Usage
The repository contains the [materials mechanics ontology repository](https://gitlab.cc-asp.fraunhofer.de/iwm-micro-mechanics-public/ontologies/materials-mechanics-ontology) as a git submodule. To clone the repository along with the submodule, please use the option `--recurse-submodules` while cloning:  
`git clone --recurse-submodules git@gitlab.cc-asp.fraunhofer.de:iwm-micro-mechanics-public/datasets/materio-miner.git`

### Dataset files
- The fine-granular TSV annotations as well as CONLL datasets corresponding to each of the four publications are provided as *<article-doi.conll>* files and *<article-doi.tsv>* files inside [dataset/fine_granular_ner](dataset/fine_granular_ner)
- The coarse-granular CONLL datasets corresponding to each of the four publications are provided as *<article-doi>.conll* files inside [dataset/coarse_granular_ner](dataset/coarse_granular_ner)
- The turtle serialization of the materials mechanics ontology is located at [materials-mechanics-ontology/materials-mechanics-ontology.ttl](materials-mechanics-ontology/materials-mechanics-ontology.ttl)

### Utitlity functions and examples
- Utility functions for fine-tuning and propagating labels are located in the [examples](examples) folder
- Example notebook that can be used for fine-tuning BERT-based language models on both CG-NER and FG-NER datasets is located at [examples/ner_finetuning.ipynb](examples/ner_finetuning.ipynb)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/git/https%3A%2F%2Fgitlab.cc-asp.fraunhofer.de%2Fiwm-micro-mechanics-public%2Fdatasets%2Fmaterio-miner/main?labpath=examples%2Fner_finetuning.ipynb)
- Example notebook showing ontological propagation of labels is located at [examples/propagate_labels.ipynb](examples/propagate_labels.ipynb)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/git/https%3A%2F%2Fgitlab.cc-asp.fraunhofer.de%2Fiwm-micro-mechanics-public%2Fdatasets%2Fmaterio-miner/main?labpath=examples%2Fpropagate_labels.ipynb)

**Usage Notes:** All example codes were tested with Python 3.8. The used packages are mentioned in [requirements.txt](requirements.txt) which can be installed using ``pip install -r requirements.txt``. Alternatively, the codes can be tested using Binder.

## Roadmap
In future dataset releases, we aim to:
- add relation extraction labels
- create a version with nested annotations for nested NER
- map other NER datasets in the MSE domain onto the proposed ontology for joint usage 
- increasing the data quantity by adding more articles.

## Contributing
Contributions to the dataset and utility functions are welcome. For annotation guidelines we refer to the accompanying publication.

## Citing the dataset
Relevant methodology for dataset generation and the technical validation of the dataset is provided in the following publication. Feel free to cite it, if you used the dataset.

Add citation here

## License
This work is licensed under a [Creative Commons Attribution 4.0 International License](https://creativecommons.org/licenses/by/4.0/).

<img src="./images/by.png" alt="license" width="160"/>

## Acknowlegement
The authors express their gratitude to the German Federal Ministry of Education and Research (BMBF) for the funding in the scope of the iBain project (13XP5118B) as part of MaterialDigital.
